<?php

namespace Litecms\Noticeuser\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Noticeuser\Models\Noticeuser;

class NoticeuserPolicy
{

    /**
     * Determine if the given user can view the noticeuser.
     *
     * @param UserPolicy $user
     * @param Noticeuser $noticeuser
     *
     * @return bool
     */
    public function view(UserPolicy $user, Noticeuser $noticeuser)
    {
        if ($user->canDo('noticeuser.noticeuser.view') && $user->isAdmin()) {
            return true;
        }

        return $noticeuser->user_id == user_id() && $noticeuser->user_type == user_type();
    }

    /**
     * Determine if the given user can create a noticeuser.
     *
     * @param UserPolicy $user
     * @param Noticeuser $noticeuser
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('noticeuser.noticeuser.create');
    }

    /**
     * Determine if the given user can update the given noticeuser.
     *
     * @param UserPolicy $user
     * @param Noticeuser $noticeuser
     *
     * @return bool
     */
    public function update(UserPolicy $user, Noticeuser $noticeuser)
    {
        if ($user->canDo('noticeuser.noticeuser.edit') && $user->isAdmin()) {
            return true;
        }

        return $noticeuser->user_id == user_id() && $noticeuser->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given noticeuser.
     *
     * @param UserPolicy $user
     * @param Noticeuser $noticeuser
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Noticeuser $noticeuser)
    {
        return $noticeuser->user_id == user_id() && $noticeuser->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given noticeuser.
     *
     * @param UserPolicy $user
     * @param Noticeuser $noticeuser
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Noticeuser $noticeuser)
    {
        if ($user->canDo('noticeuser.noticeuser.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given noticeuser.
     *
     * @param UserPolicy $user
     * @param Noticeuser $noticeuser
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Noticeuser $noticeuser)
    {
        if ($user->canDo('noticeuser.noticeuser.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
